class FaqsController < ApplicationController
  def index
    faqs = Qa.can_display.order_by(:order_position => "asc").filter_by_categories
      f = faqs.collect do |qa|
       statuses = qa.statuses_with_classname.collect do |status|
        {
          "status" => status["name"],
          "status-class" => "status-#{status['classname']}"
        }
      end
      {
        "link_to_show" => OrbitHelper.url_to_show(qa.to_param),
        "question" => qa.title,
        "answer" => qa.answer,
        "statuses" => statuses
      }
    end
    {
        "faqs" => f,
        "extras" => {"widget-title"=>"Faqs"},
        "total_pages" => faqs.total_pages
      } 
  end

  def show
    params = OrbitHelper.params
    faq = Qa.can_display.find_by_param(params[:uid])

    url_to_edit = OrbitHelper.user_can_edit?(faq) ? "/admin/faqs/#{faq.id.to_s}/edit" : ""
    
    return {} if (faq.category.disable rescue false)

    faqs_files = faq.qa_files.collect do |f|
      {
        "file_url" => f.file.url,
        "file_title" => f.title
      }
    end
    faqs_links = faq.qa_links.collect do |f|
      {
        "link_url" => f.url,
        "link_title" => f.title
      }
    end
    tags = faq.tags.map{|tag|  { "tag" => tag.name } } rescue []
    temp_rich_title = Nokogiri::HTML(faq.rich_title).css('body')
    temp_rich_title.children.each_with_index do |child,i|
      temp_rich_title.children[i].attribute('style').value = child.attribute('style').value.gsub(/\b(?:font-size\s*?:\s*([^;>]*?)(?=[;">}]))/,'')
    end
    {
      "extras" => {"question" => temp_rich_title,"answer" => faq.answer},
      "faqs_links" => faqs_links,
      "faqs_files" => faqs_files,
      "tags" => tags,
      "url_to_edit" => url_to_edit
    }
  end

  def widget
    faqs = Qa.filter_by_widget_categories.collect do |qa|
      statuses = qa.statuses_with_classname.collect do |status|
          {
              "status" => status["name"],
              "status-class" => "status-#{status['classname']}"
          }
        end
      {
        "link_to_show" => OrbitHelper.widget_item_url(qa.to_param),
        "title" => qa.title,
        "postdate" => qa.created_at.strftime('%Y-%m-%d %H:%M'),
        "statuses" => statuses
      }
    end
    {
        "faqs" => faqs,
        "extras" => {"widget-title"=>"Faqs","more_url"=>OrbitHelper.widget_more_url}
      } 
  end
end